@@ -2,8 +2,8 @@
 #
 # est.map.R
 #
-# copyright (c) 2001-4, Karl W Broman, Johns Hopkins University
-# last modified Nov, 2004
+# copyright (c) 2001-5, Karl W Broman, Johns Hopkins University
+# last modified Oct, 2005
 # first written Apr, 2001
 # Licensed under the GNU General Public License version 2 (June, 1991)
 # 
@@ -19,7 +19,7 @@
 ######################################################################
 
 est.map <- 
-function(cross, error.prob=0, map.function=c("haldane","kosambi","c-f","morgan"),
+function(cross, error.prob=0.0001, map.function=c("haldane","kosambi","c-f","morgan"),
          maxit=4000, tol=1e-4, sex.sp=TRUE, verbose=FALSE)
 {
 
