@@ -3,7 +3,7 @@
 # read.cross.csv.R
 #
 # copyright (c) 2000-5, Karl W Broman, Johns Hopkins University
-# last modified Sep, 2005
+# last modified Oct, 2005
 # first written Aug, 2000
 # Licensed under the GNU General Public License version 2 (June, 1991)
 #
@@ -23,7 +23,8 @@
 
 read.cross.csv <-
 function(dir, file, na.strings=c("-","NA"),
-         genotypes=c("A","H","B","D","C"), estimate.map=TRUE, ...)
+         genotypes=c("A","H","B","D","C"),
+         estimate.map=TRUE, rotate=FALSE, ...)
 {
   # create file names
   if(missing(file)) file <- "data.csv"
@@ -44,6 +45,11 @@ function(dir, file, na.strings=c("-","NA"),
                        colClasses="character", fill=TRUE,
                        blank.lines.skip=TRUE, ...)
 
+  if(rotate) {
+    data <- as.data.frame(t(data))
+    for(i in 1:ncol(data)) data[,i] <- as.character(data[,i])
+  }
+
   # determine number of phenotypes based on initial blanks in row 2
   n <- ncol(data)
   temp <- rep(FALSE,n)
@@ -51,6 +57,7 @@ function(dir, file, na.strings=c("-","NA"),
     temp[i] <- all(data[2,1:i]=="")
     if(!temp[i]) break
   }
+
   if(!any(temp)) # no phenotypes!
     stop("You must include at least one phenotype (e.g., an index).")
   n.phe <- max((1:n)[temp])
